@@ -144,7 +144,7 @@ echo "duplicates: $(reads-diff bam "$BASE_PATH.with_duplicates.bam" bam "$BASE_P
 # --- 5 BIGWIG ---
 echo "# bigwig: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bamCoverage -b "$BASE_PATH.bam" -o "$BASE_PATH.cpm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing BPM -p "$CPU_CORES"
-bamCoverage -b "$BASE_PATH.with_duplicates.bam" -o "$BASE_PATH.with_duplicates.cpm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing BPM -p "$CPU_CORES"
+[ "$BAM_WITH_DUPLICATES" != remove ] && bamCoverage -b "$BASE_PATH.with_duplicates.bam" -o "$BASE_PATH.with_duplicates.cpm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing BPM -p "$CPU_CORES"
 
 
 # --- [ COPY BACK TO ORIGINAL LOCATION ] ---
@@ -154,10 +154,10 @@ mv "$BASE_PATH.qc" "$ORIGINAL_BASE_PATH.qc" &
 mv "$BASE_PATH.bismark_report.txt" "$ORIGINAL_BASE_PATH.bismark_report.txt" &
 mv "$BASE_PATH.bam" "$ORIGINAL_BASE_PATH.bam" &
 mv "$BASE_PATH.bam.bai" "$ORIGINAL_BASE_PATH.bam.bai" &
-mv "$BASE_PATH.with_duplicates.bam" "$ORIGINAL_BASE_PATH.with_duplicates.bam" &
-mv "$BASE_PATH.with_duplicates.bam.bai" "$ORIGINAL_BASE_PATH.with_duplicates.bam.bai" &
+[ "$BAM_WITH_DUPLICATES" != remove ] && mv "$BASE_PATH.with_duplicates.bam" "$ORIGINAL_BASE_PATH.with_duplicates.bam" &
+[ "$BAM_WITH_DUPLICATES" != remove ] && mv "$BASE_PATH.with_duplicates.bam.bai" "$ORIGINAL_BASE_PATH.with_duplicates.bam.bai" &
 mv "$BASE_PATH.cpm.bigwig" "$ORIGINAL_BASE_PATH.cpm.bigwig" &
-mv "$BASE_PATH.cpm.bigwig" "$ORIGINAL_BASE_PATH.with_duplicates.cpm.bigwig" &
+[ "$BAM_WITH_DUPLICATES" != remove ] && mv "$BASE_PATH.with_duplicates.cpm.bigwig" "$ORIGINAL_BASE_PATH.with_duplicates.cpm.bigwig" &
 wait
 BASE_PATH="$ORIGINAL_BASE_PATH"
 
